<!DOCTYPE TS><TS>
<context>
    <name>AddRecording</name>
    <message>
        <source>Schedule a:</source>
        <translation>Programar:</translation>
    </message>
    <message>
        <source>&amp;Recording</source>
        <translation>&amp;Grabación</translation>
    </message>
    <message>
        <source>&amp;Playout</source>
        <translation>&amp;Reproducción</translation>
    </message>
    <message>
        <source>&amp;Macro Cart</source>
        <translation>Cartucho &amp;Macro</translation>
    </message>
    <message>
        <source>&amp;Switch Event</source>
        <translation>&amp;Evento con la Suichera</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Descarga</translation>
    </message>
    <message>
        <source>&amp;Upload</source>
        <translation>&amp;Subida</translation>
    </message>
</context>
<context>
    <name>CatchListView</name>
    <message>
        <source>Edit Cue Markers</source>
        <translation>Editar marcadores Cue</translation>
    </message>
</context>
<context>
    <name>DeckMon</name>
    <message>
        <source>MON</source>
        <translation>MON</translation>
    </message>
    <message>
        <source>ABORT</source>
        <translation>ABORTAR</translation>
    </message>
    <message>
        <source>OFFLINE</source>
        <translation>OFFLINE</translation>
    </message>
    <message>
        <source>L</source>
        <translation>Iz</translation>
    </message>
    <message>
        <source>R</source>
        <translation>De</translation>
    </message>
    <message>
        <source>IDLE</source>
        <translation>IDLE</translation>
    </message>
    <message>
        <source>READY</source>
        <translation>LISTO</translation>
    </message>
    <message>
        <source>WAITING</source>
        <translation>ESPERA</translation>
    </message>
    <message>
        <source>RECORDING</source>
        <translation>GRABANDO</translation>
    </message>
    <message>
        <source>PLAYING</source>
        <translation>REPROD</translation>
    </message>
    <message>
        <source>[no description]</source>
        <translation>[sin descripción]</translation>
    </message>
    <message>
        <source>[multiple events]</source>
        <translation>[múltiples eventos]</translation>
    </message>
    <message>
        <source>[unknown cut]</source>
        <translation>[audio desconocido]</translation>
    </message>
</context>
<context>
    <name>EditCartEvent</name>
    <message>
        <source>Edit Cart Event</source>
        <translation>Editar evento de cartucho</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Evento activo</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Ubicación:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Hora inicio:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descripción:</translation>
    </message>
    <message>
        <source>Cart Number:</source>
        <translation>Nro. cartucho:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Seleccionar</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Días activos</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Lunes</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Martes</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Miércoles</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Jueves</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Viernes</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Una sola vez</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Invalid Cart</source>
        <translation>Cartucho inválido</translation>
    </message>
    <message>
        <source>That cart doesn&apos;t exist!</source>
        <translation>¡El cartucho no existe!</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Evento duplicado</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>¡Un evento con esos parámetros ya existe!</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Guardar
como nuevo</translation>
    </message>
</context>
<context>
    <name>EditDownload</name>
    <message>
        <source>Edit Download</source>
        <translation>Edtar Descarga</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Evento Activo</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Ubicación:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Hora Inicio:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descripción:</translation>
    </message>
    <message>
        <source>Url:</source>
        <translation>Url:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Usuario:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contraseña:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Destino:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Seleccionar</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Días activo</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Lunes</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Martes</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Miércoles</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Jueves</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Viernes</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation></translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Una sola vez</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Invalid URL</source>
        <translation>URL inválido</translation>
    </message>
    <message>
        <source>The URL is invalid!</source>
        <translation>¡El URL es inválido!</translation>
    </message>
    <message>
        <source>Unsupported URL protocol!</source>
        <translation>¡Protocolo de URL no soportado!</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Evento duplicado</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>¡Un evento con esos parámetros ya existe!</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Guardar
como Nuevo</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Autorecortar</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizar</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Canales:</translation>
    </message>
    <message>
        <source>Event Offset:</source>
        <translation>Desplaz.Evento:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>días</translation>
    </message>
    <message>
        <source>Missing Username</source>
        <translation>Falta el usuario</translation>
    </message>
    <message>
        <source>You must specify a username!</source>
        <translation>¡Debe especificar un nombre de usuario!</translation>
    </message>
    <message>
        <source>Update Library Metadata</source>
        <translation>Actualizar metadatos en biblioteca</translation>
    </message>
</context>
<context>
    <name>EditPlayout</name>
    <message>
        <source>Edit Playout</source>
        <translation>Editar Reproducción</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Evento activo</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Ubicación:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Hora Inicio:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descripción:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Destino:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Seleccionar</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Días Activo</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Lunes</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Martes</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Miércoles</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Jueves</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Viernes</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Una sola vez</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Evento duplicado</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>¡Un evento con esos parámetros ya existe!</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Guardar 
como Nuevo</translation>
    </message>
</context>
<context>
    <name>EditRecording</name>
    <message>
        <source>Edit Recording</source>
        <translation>Edtar Grabación</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Evento activo</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Ubicación:</translation>
    </message>
    <message>
        <source>Start Parameters</source>
        <translation>Parámetros de Inicio</translation>
    </message>
    <message>
        <source>Use Hard Time</source>
        <translation>Hora estricta</translation>
    </message>
    <message>
        <source>Record Start Time:</source>
        <translation>Inicio de grabación:</translation>
    </message>
    <message>
        <source>Use GPI</source>
        <translation>Usar GPI</translation>
    </message>
    <message>
        <source>Window Start Time:</source>
        <translation>Margen de inicio:</translation>
    </message>
    <message>
        <source>GPI Matrix:</source>
        <translation>Matriz GPI:</translation>
    </message>
    <message>
        <source>GPI Line:</source>
        <translation>Línea GPI:</translation>
    </message>
    <message>
        <source>Start Delay:</source>
        <translation>Demora en Inicio:</translation>
    </message>
    <message>
        <source>End Parameters</source>
        <translation>Parámetros de Fin</translation>
    </message>
    <message>
        <source>Use Length</source>
        <translation>Usar duración</translation>
    </message>
    <message>
        <source>Record Length:</source>
        <translation>Duración de Grabación:</translation>
    </message>
    <message>
        <source>Record End Time:</source>
        <translation>Hora fin de grabación:</translation>
    </message>
    <message>
        <source>Window End Time:</source>
        <translation>Margen de fin:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descripción:</translation>
    </message>
    <message>
        <source>Source:</source>
        <translation>Fuente:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Destino:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Seleccionar</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Días activo</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Lunes</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Martes</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Miércoles</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Jueves</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Viernes</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Start Date Offset:</source>
        <translation>Desplaz. Fecha Inicio:</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nada</translation>
    </message>
    <message>
        <source>End Date Offset:</source>
        <translation>Desplaz. Fecha Fin:</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Canales:</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Una sola vez</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Missing Cut</source>
        <translation>Audio no encontrado</translation>
    </message>
    <message>
        <source>You must assign a record cut!</source>
        <translation>¡Debe asignar un audio para la grabación!</translation>
    </message>
    <message>
        <source>Record Parameter Error</source>
        <translation>Error de parámetros de la grabación</translation>
    </message>
    <message>
        <source>The start GPI window cannot end before it begins!</source>
        <translation>¡La ventana GPI inicial no puede terminar antes de que empiece!</translation>
    </message>
    <message>
        <source>The recording cannot end before it begins!</source>
        <translation>¡La grabación no puede terminar antes de que empiece!</translation>
    </message>
    <message>
        <source>The end GPI window cannot end before it begins!</source>
        <translation>¡La ventana GPI final no puede terminar antes de que empiece!</translation>
    </message>
    <message>
        <source>The start GPI matrix doesn&apos;t exist!</source>
        <translation>¡La matriz GPI de inicio no existe!</translation>
    </message>
    <message>
        <source>The start GPI line doesn&apos;t exist!</source>
        <translation>¡La línea GPI de inicio no existe!</translation>
    </message>
    <message>
        <source>The end GPI matrix doesn&apos;t exist!</source>
        <translation>¡La matriz GPI final no existe!</translation>
    </message>
    <message>
        <source>The end GPI line doesn&apos;t exist!</source>
        <translation>¡La línea GPi final no existe!</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Guardar
como Nuevo</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Evento duplicado</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>¡Un evento con esos parámetros ya existe!</translation>
    </message>
    <message>
        <source>Max Record Length:</source>
        <translation>Máx Duración de la Grabación:</translation>
    </message>
    <message>
        <source>Allow Multiple Recordings within this Window</source>
        <translation>Permitir múltiples grabaciones en esta ventana</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Autorecortar</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizar</translation>
    </message>
</context>
<context>
    <name>EditSwitchEvent</name>
    <message>
        <source>Edit Switcher Event</source>
        <translation>Editar Eventos de Suichera</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Evento Activo</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Ubicación:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Tiempo Inicio:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descripción:</translation>
    </message>
    <message>
        <source>Switch Matrix:</source>
        <translation>Matriz de Suich.:</translation>
    </message>
    <message>
        <source>Switch Input:</source>
        <translation>Entrada de Suich.:</translation>
    </message>
    <message>
        <source>Switch Output:</source>
        <translation>Salida de Suich.:</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Días Activo</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Lunes</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Martes</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Miércoles</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Jueves</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Viernes</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Una sola vez</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Evento duplicado</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>¡Un evento con esos parámetros ya existe!</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Guardar
como Nuevo</translation>
    </message>
    <message>
        <source>--OFF--</source>
        <translation>--APAGADO--</translation>
    </message>
</context>
<context>
    <name>EditUpload</name>
    <message>
        <source>Edit Upload</source>
        <translation>Editar Subida</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Evento Activo</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Ubicación:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Tiempo de Inicio:</translation>
    </message>
    <message>
        <source>Source:</source>
        <translation>Fuente:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Seleccionar</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descripción:</translation>
    </message>
    <message>
        <source>Url:</source>
        <translation>Url:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Usuario:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contraseña:</translation>
    </message>
    <message>
        <source>S&amp;et</source>
        <translation>Po&amp;ner</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Días activos</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Lunes</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Martes</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Miércoles</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Jueves</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Viernes</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation></translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Una sola vez</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Invalid URL</source>
        <translation>URL inválido</translation>
    </message>
    <message>
        <source>The URL is invalid!</source>
        <translation>¡El URL es inválido!</translation>
    </message>
    <message>
        <source>Unsupported URL protocol!</source>
        <translation>¡Protocolo de URL no soportado!</translation>
    </message>
    <message>
        <source>Export Format:</source>
        <translation>Formato Exportac.:</translation>
    </message>
    <message>
        <source>Unsupported Format</source>
        <translation>Formato no soportado</translation>
    </message>
    <message>
        <source>The currently selected export format is unsupported on this host!</source>
        <translation>¡El formato seleccionado no está soportado por este equipo!</translation>
    </message>
    <message>
        <source>The currently selected export format is unsupported on host </source>
        <translation>El formato de exportación seleccionado no está soportado en el equipo </translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizar</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Guardar
como Nuevo</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Evento duplicado</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>¡Un evento con esos parámetros ya existe!</translation>
    </message>
    <message>
        <source>RSS Feed:</source>
        <translation>Flujo RSS:</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[ninguno]</translation>
    </message>
    <message>
        <source>Event Offset:</source>
        <translation>Desplaz. Evento:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>días</translation>
    </message>
    <message>
        <source>Missing Username</source>
        <translation>Falta el usuario</translation>
    </message>
    <message>
        <source>You must specify a username!</source>
        <translation>¡Debe especificar un nombre de usuario!</translation>
    </message>
    <message>
        <source>Export Library Metadata</source>
        <translation>Exportar Bibliot. Metadatos</translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>RDLibrary Reports</source>
        <translation>Reportes RDLibrary</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation>&amp;Generar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>Event Report</source>
        <translation>Reporte de Evento</translation>
    </message>
    <message>
        <source>Upload/Download Report</source>
        <translation>Reporte Subidas/Descargas</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCatch - Host:</source>
        <translation type="obsolete">RDCatch - Computador:</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>No puedo conectarme</translation>
    </message>
    <message>
        <source>Show Only Active Events</source>
        <translation>Ver sólo eventos activos</translation>
    </message>
    <message>
        <source>Show Only Today&apos;s Events</source>
        <translation>Ver sólo eventos de hoy</translation>
    </message>
    <message>
        <source>Show DayOfWeek:</source>
        <translation>Mostrar Día de Semana:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Días de semana</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Lunes</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Martes</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Miércoles</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Jueves</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Viernes</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>DESCRIPCIÓN</translation>
    </message>
    <message>
        <source>LOCATION</source>
        <translation>UBICACIÓN</translation>
    </message>
    <message>
        <source>START</source>
        <translation>INICIO</translation>
    </message>
    <message>
        <source>END</source>
        <translation>FIN</translation>
    </message>
    <message>
        <source>SOURCE</source>
        <translation>FUENTE</translation>
    </message>
    <message>
        <source>DESTINATION</source>
        <translation>DESTINO</translation>
    </message>
    <message>
        <source>ONE SHOT</source>
        <translation>UNA VEZ</translation>
    </message>
    <message>
        <source>TRIM THRESHOLD</source>
        <translation>RECORTAR NIVEL</translation>
    </message>
    <message>
        <source>STARTDATE OFFSET</source>
        <translation>DESPLAZ. FECHA INICIO</translation>
    </message>
    <message>
        <source>ENDDATE OFFSET</source>
        <translation>DESPLAZ. FECHA FIN</translation>
    </message>
    <message>
        <source>FORMAT</source>
        <translation>FORMATO</translation>
    </message>
    <message>
        <source>CHANNELS</source>
        <translation>CANALES</translation>
    </message>
    <message>
        <source>SAMPLE RATE</source>
        <translation>TASA DE SAMPLEO</translation>
    </message>
    <message>
        <source>BIT RATE</source>
        <translation>TASA DE BITS</translation>
    </message>
    <message>
        <source>STATION</source>
        <translation>ESTACIÓN</translation>
    </message>
    <message>
        <source>DECK</source>
        <translation>DECK</translation>
    </message>
    <message>
        <source>CUT</source>
        <translation>AUDIO</translation>
    </message>
    <message>
        <source>CART</source>
        <translation>CARTUCHO</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TIPO</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Añadir</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Deslizar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>Are you sure you want to delete event</source>
        <translation>Desea borrar el evento</translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation>Borrar evento</translation>
    </message>
    <message>
        <source>Control connection timed out to host</source>
        <translation>La conexión de control no pudo realizarse</translation>
    </message>
    <message>
        <source>Su</source>
        <translation>Do</translation>
    </message>
    <message>
        <source>Mo</source>
        <translation>Lu</translation>
    </message>
    <message>
        <source>Tu</source>
        <translation>Ma</translation>
    </message>
    <message>
        <source>We</source>
        <translation>Mi</translation>
    </message>
    <message>
        <source>Th</source>
        <translation>Ju</translation>
    </message>
    <message>
        <source>Fr</source>
        <translation>Vi</translation>
    </message>
    <message>
        <source>Sa</source>
        <translation>Sa</translation>
    </message>
    <message>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <source>Hard</source>
        <translation>Estricto</translation>
    </message>
    <message>
        <source>Gpi</source>
        <translation>Gpi</translation>
    </message>
    <message>
        <source>Len</source>
        <translation>Lon</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Cart</source>
        <translation>Cartucho</translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation>ORIGEN</translation>
    </message>
    <message>
        <source>STATUS</source>
        <translation>ESTADO</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation></translation>
    </message>
    <message>
        <source>MPEG Layer 1</source>
        <translation></translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation></translation>
    </message>
    <message>
        <source>MPEG Layer 3</source>
        <translation></translation>
    </message>
    <message>
        <source>FLAC</source>
        <translation></translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation></translation>
    </message>
    <message>
        <source>STATE</source>
        <translation>ESTADO</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Evento activo</translation>
    </message>
    <message>
        <source>You cannot edit an active event!</source>
        <translation>¡No puede editar un evento activo!</translation>
    </message>
    <message>
        <source>EXIT CODE</source>
        <translation>COD DE SALIDA</translation>
    </message>
    <message>
        <source>Unable to connect to Core AudioEngine</source>
        <translation>No pude conectar al Core AudioEngine</translation>
    </message>
    <message>
        <source>Reports</source>
        <translation>Reportes</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[ninguno]</translation>
    </message>
    <message>
        <source>rdcatch : </source>
        <translation>rdcatch : </translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCM24</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Event Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Types</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
